@@ -4,7 +4,7 @@
 #
 "df2latex" <- 
 function(x,digits=2,rowlabels=TRUE,apa=TRUE,short.names=TRUE,
-font.size ="scriptsize",big.mark=NULL, drop.na=TRUE, heading="A table from R",
+font.size ="scriptsize",big.mark=NULL, drop.na=TRUE, heading="A table from the psych package in R",
 caption="df2latex",label="default",char=FALSE,stars=FALSE) {
 #first set up the table
  nvar <- dim(x)[2]
@@ -120,7 +120,7 @@ if (!is.na(class(x)[2]) & class(x)[2]=="corr.test") {  #we already did the analy
 }
 
 "fa2latex" <- 
-function(f,digits=2,rowlabels=TRUE,apa=TRUE,short.names=FALSE,cumvar=FALSE,font.size ="scriptsize", heading="A factor analysis table from the psych package in R",caption="fa2latex",label="default") {
+function(f,digits=2,rowlabels=TRUE,apa=TRUE,short.names=FALSE,cumvar=FALSE,cut=0,font.size ="scriptsize", heading="A factor analysis table from the psych package in R",caption="fa2latex",label="default") {
 if(class(f)[2] !="fa") f <- f$fa
 x <- unclass(f$loadings)
 if(!is.null(f$Phi)) {Phi <- f$Phi} else {Phi <- NULL}
@@ -154,7 +154,9 @@ footer <- paste(footer,"
 
 
 #now put the data into it
+ 
  x <- round(x,digits=digits)
+ x[abs(x) < cut] <- NA
  cname <- colnames(x)
  if (short.names) cname <- 1:nvar
  names1 <- paste(cname[1:(nvar-1)], " & ")
@@ -162,7 +164,9 @@ footer <- paste(footer,"
  
  if(apa)  {allnames <- c("Variable  &  ",names1,lastname," \\hline \n")} else {allnames <- c("  &  ",names1,lastname,"\\cr \n")}
  x <- format(x,drop0trailing=FALSE)  #to keep the digits the same
+ 
  value <- apply(x,1,paste,collapse="  &  ") #insert & between columns
+ value <- gsub("NA", "  ", value, fixed = TRUE)
  if(rowlabels) value <- {paste(sanitize.latex(names(value)),"  & ",value)} else {paste("  &  ",value)}
  values <- paste(value, "\\cr", "\n")  #add \\cr at the end of each row
 
@@ -174,7 +178,7 @@ footer <- paste(footer,"
  
  
  #now find and show the variance accounted for
- x <- f$loadings     #use the original values
+ x <- f$loadings     #use the original values not the rounded ones
  nvar <- nrow(x)
   if(is.null(Phi)) {if(nfactors > 1)  {vx <- colSums(x^2) } else {
                                       vx <- diag(t(x) %*% x)
@@ -183,7 +187,9 @@ footer <- paste(footer,"
       	                                      vx <- vx*nvar/vtotal }
       	  #names(vx) <- colnames(x)[1:nvar]
       	  vx <- round(vx,digits) 
+      	  
           loads <- c("\\hline \\cr SS loadings &",paste(vx," & ",sep=""),"\\cr  \n")
+           
           cat(loads)
            
           #varex <- rbind("SS loadings " =   vx)
@@ -289,3 +295,132 @@ return(result)
 }
  
 
+ 
+ 
+ #added December 28, 2013
+ "omega2latex" <- 
+function(f,digits=2,rowlabels=TRUE,apa=TRUE,short.names=FALSE,cumvar=FALSE,cut=.2,font.size ="scriptsize", heading="An omega analysis table from the psych package in R",caption="omega2latex",label="default") {
+if(class(f)[2] == "omega" ) f$loadings <- f$schmid$sl
+x <- unclass(f$loadings)
+
+nfactors <- ncol(x)
+
+h2 <- rowSums(x^2)
+u2 <- 1- h2
+vtotal <- sum(h2 + u2)
+
+#first set up the table
+ nvar <- dim(x)[2]
+comment <- paste("% Called in the psych package ", match.call())
+header <- paste("\\begin{",font.size,"} \\begin{table}[htdp]",
+"\\caption{",caption," with cut = ",cut,"\n $\\omega_h  = ",round(f$omega_h,digits), "\\;\\;\\;\\alpha (\\lambda_3) = ",round(f$alpha,digits), "\\;\\;\\;\\lambda_6^* = ",round(f$G6,digits),"\\;\\;\\; \\omega_t = ",round(f$omega.tot,digits),"$ }
+\\begin{center}
+\\begin{tabular}",sep="")
+header <- c(header,"{l",rep("r",nvar),"}\n")
+if(apa) header <- c(header,
+"\\multicolumn{",nvar,"}{l}{",heading,"}",
+'\\cr \n \\hline ')
+if(apa) {footer <- paste(" \\hline ")} 
+footer <- paste(footer,"
+\\end{tabular}
+\\end{center}
+\\label{",label,"}
+\\end{table} 
+\\end{",font.size,"}
+",sep=""
+)
+
+#now put the data into it
+ x[abs(x) < cut] <- NA
+ x <- round(x,digits=digits)
+ cname <- colnames(x)
+ if (short.names) cname <- 1:nvar
+ names1 <- paste(cname[1:(nvar-1)], " & ")
+ lastname <- paste(cname[nvar],"\\cr \n")
+ 
+ if(apa)  {allnames <- c("Variable  &  ",names1,lastname," \\hline \n")} else {allnames <- c("  &  ",names1,lastname,"\\cr \n")}
+ x <- format(x,drop0trailing=FALSE)  #to keep the digits the same
+ value <- apply(x,1,paste,collapse="  &  ") #insert & between columns
+ value <- gsub("NA", "  ", value, fixed = TRUE)
+ if(rowlabels) value <- {paste(sanitize.latex(names(value)),"  & ",value)} else {paste("  &  ",value)}
+ values <- paste(value, "\\cr", "\n")  #add \\cr at the end of each row
+
+ #now put it all together
+ cat(comment,"\n")  #a comment field saying where the data came from
+ cat(header)   #the header information
+ cat(allnames) #the variable names
+ cat(values)  #the factor loadings
+ 
+ #now find and show the variance accounted for
+ x <- f$loadings     #use the original values
+ nvar <- nrow(x)
+vx <- colSums(x^2)[1:(ncol(x)-3)]
+vx <- round(vx,digits) 
+loads <- c("\\hline \\cr SS loadings &",paste(vx," & ",sep=""),"\\cr  \n")
+cat(loads)
+cat(footer)   #close it up with a footer
+ }
+
+
+
+#added 1/6/14
+"ICC2latex" <- 
+function(icc,digits=2,rowlabels=TRUE,apa=TRUE,ci=TRUE,
+font.size ="scriptsize",big.mark=NULL, drop.na=TRUE, heading="A table from the psych package in R",
+caption="ICC2latex",label="default",char=FALSE) {
+if((length(class(icc)) < 2 ) | (class(icc)[2] !="ICC")) icc <- ICC(icc)  #do the analysis in case we have not done it yet
+#first set up the table
+x <- icc$results
+ nvar <- dim(x)[2]
+ rname<- rownames(x)
+comment <- paste("%", match.call())
+header <- paste("\\begin{",font.size,"} \\begin{table}[htdp]",
+"\\caption{",caption,"}
+\\begin{tabular}",sep="")
+
+if(rowlabels) { header <- c(header,"{l",rep("r",(nvar)),"}\n")} else {header <- c(header,"{",rep("r",(nvar+1)),"}\n")
+               }
+if(apa) {header <- c(header,
+"\\multicolumn{",5,"}{l}{",heading,"}", '\\cr \n \\hline ')
+footer <- paste(" \\hline \\cr \\multicolumn{ 5 }{c}{   Number of subjects = ", icc$n.obs, "Number of raters = ",icc$n.judge,"}")}  else {footer <- NULL}
+
+
+footer <- paste(footer,"
+\\end{tabular}
+\\label{",label,"}
+\\end{table} 
+\\end{",font.size,"}
+",sep=""
+)
+
+#now put the data into it
+
+x[2:nvar] <- try(round(x[2:nvar],digits=digits)) 
+    
+ 
+ cname <- colnames(x)
+ if(!ci) nvar <- nvar-2
+ names1 <- paste(cname[1:(nvar-1)], " & ")
+ lastname <- paste(cname[nvar],"\\cr \n")
+ 
+if(apa)  {allnames <- c("Variable  &  ",names1,lastname," \\hline \n")} else {if(rowlabels) {allnames <- c("  &  ",names1,lastname,"\\cr \n")} else {
+             allnames <- c(names1,lastname,"\\cr \n")}}
+if(!char) {if(is.null(big.mark)) { x <- format(x[1:nvar],drop0trailing=FALSE)} else   #to keep the digits the same
+                      {x <- prettyNum(x,big.mark=",",drop0trailing=FALSE)} 
+   }   
+ value <- apply(x,1,paste,collapse="  &  ") #insert & between columns
+
+ if(rowlabels) {value <- paste(sanitize.latex(rname),"  & ",value)} else {value <- paste("  & ",value)}
+ values <- paste(value, "\\cr", "\n")  #add \\cr at the end of each row
+ if(drop.na) values <- gsub("NA","  ",values,fixed=TRUE)
+
+ #now put it all together
+ cat(comment,"\n")  #a comment field saying where the data came from
+ cat(header)   #the header information
+ cat(allnames) #the variable names
+ cat(values)  #the data
+ cat(footer)   #close it up with a footer
+
+ }
+ 
+
