@@ -23,6 +23,12 @@ cat("Factor Analysis with confidence intervals using method = ",x$f$fm )
    print (round(lci,digits=digits))
   if(!is.null(x$fa$Phi)) { phis <- x$fa$Phi[lower.tri(x$fa$Phi)]
    cci <- data.frame(lower=x$ci.rot$lower,estimate = phis,upper= x$ci.rot$upper)
+  
+    cnR <- abbreviate(colnames(x$fa$loadings),minlength=5) 
+      k <- 1
+     for(i in 1:(nfactors-1)) {for (j in (i+1):nfactors) {
+      rownames(cci)[k] <- paste(cnR[i],cnR[j],sep="-")
+      k<- k +1 }}  #added 10/4/14
    cat("\n Interfactor correlations and bootstrapped confidence intervals \n")
    print(cci,digits=digits)}
    
